Large code cleanups:
[mailer.git] / ref.php
diff --git a/ref.php b/ref.php
index 81d8df238c263bfdf51c2752644e0482c6dc1477..6683a7603c1250f0ca6df7eb30c6b2eae1daa38a 100644 (file)
--- a/ref.php
+++ b/ref.php
@@ -6,9 +6,9 @@
  * -------------------------------------------------------------------- *
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
* Short description : Redirection for the referal link                 *
  * -------------------------------------------------------------------- *
* Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *
  * $Date::                                                            $ *
@@ -51,11 +51,11 @@ setContentType('text/html');
 // No refid by default
 $url = 'modules.php?module=index';
 
-// Check for determined referal id
-if ((isExtensionActive('user')) && (isReferalIdValid()) && (isValidUserId(determineReferalId()))) {
+// Check for determined referral id
+if ((isExtensionActive('user')) && (isReferralIdValid()) && (isValidUserId(determineReferralId()))) {
        // Update ref counter
        SQL_QUERY_ESC("UPDATE `{?_MYSQL_PREFIX?}_user_data` SET `ref_clicks`=`ref_clicks`+1 WHERE `userid`=%s LIMIT 1",
-               array(makeZeroToNull(determineReferalId())), __FILE__, __LINE__);
+               array(makeZeroToNull(determineReferralId())), __FILE__, __LINE__);
 
        // Base URL for redirection
        switch (getConfig('refid_target')) {
@@ -6,9 +6,9 @@
  * File              : ref.php                                          *
  * -------------------------------------------------------------------- *
- * Short description : Redirection for the referal link                 *
+ * Short description : Redirection for the referral link                *
  * -------------------------------------------------------------------- *
@@ -6,9 +6,9 @@
  * -------------------------------------------------------------------- *
- * Kurzbeschreibung  : Weiterleitungsscript fuer die Referal-Links      *
+ * Kurzbeschreibung  : Weiterleitungsscript fuer die Referral-Links     *
  * -------------------------------------------------------------------- *
  * $Revision::                                                        $ *